@@ -17,11 +17,11 @@
 //! - calendar.txt and calendar_dates.txt format are identical between the GTFS
 //!   and NTFS
 
+use crate::file_handler::FileHandler;
 use crate::model::Collections;
 use crate::objects::{self, Date, ExceptionType};
-use crate::read_utils::{read_objects, FileHandler};
-use crate::utils::*;
-use crate::utils::{de_from_date_string, ser_from_naive_date};
+use crate::parser::read_objects;
+use crate::serde_utils::*;
 use crate::vptranslator::translate;
 use crate::Result;
 use anyhow::{anyhow, bail, Context};
@@ -167,7 +167,10 @@ where
     Ok(())
 }
 
-pub(crate) fn manage_calendars<H>(file_handler: &mut H, collections: &mut Collections) -> Result<()>
+pub(crate) fn _manage_calendars<H>(
+    file_handler: &mut H,
+    collections: &mut Collections,
+) -> Result<()>
 where
     for<'a> &'a mut H: FileHandler,
 {
@@ -189,6 +192,22 @@ where
     Ok(())
 }
 
+#[cfg(not(feature = "parser"))]
+pub(crate) fn manage_calendars<H>(file_handler: &mut H, collections: &mut Collections) -> Result<()>
+where
+    for<'a> &'a mut H: FileHandler,
+{
+    _manage_calendars(file_handler, collections)
+}
+#[cfg(feature = "parser")]
+/// Read calendar_dates.txt and calendar.txt files
+pub fn manage_calendars<H>(file_handler: &mut H, collections: &mut Collections) -> Result<()>
+where
+    for<'a> &'a mut H: FileHandler,
+{
+    _manage_calendars(file_handler, collections)
+}
+
 /// Write the calendar_dates.txt file into a Path from a list of Calendar
 pub fn write_calendar_dates(
     path: &path::Path,
