@@ -121,14 +121,13 @@ pub struct Collections {
 impl Collections {
     /// Remove associated schedules with route points
     pub fn remove_route_points(&mut self) {
-        let vj_idxs: Vec<Idx<VehicleJourney>> =
-            self.vehicle_journeys.iter().map(|(idx, _)| idx).collect();
         let is_route_point = |stop_time: &StopTime| -> bool {
             stop_time.pickup_type == 3 || stop_time.drop_off_type == 3
         };
-        for vj_idx in vj_idxs {
+        for vj_idx in self.vehicle_journeys.indexes() {
             let mut vj = self.vehicle_journeys.index_mut(vj_idx);
             vj.stop_times.retain(|stop_time| !is_route_point(stop_time));
+            vj.stop_times.shrink_to_fit();
         }
     }
 
@@ -276,7 +275,7 @@ impl Collections {
         let mut stop_area_ids_used: HashSet<String> = HashSet::new();
         let mut equipments_used: HashSet<String> = HashSet::new();
 
-        let stop_locations = self
+        let mut stop_locations = self
             .stop_locations
             .take()
             .into_iter()
@@ -301,6 +300,9 @@ impl Collections {
                 if let Some(level_id) = &sl.level_id {
                     level_id_used.insert(level_id.clone());
                 }
+                if let Some(equipment_id) = &sl.equipment_id {
+                    equipments_used.insert(equipment_id.clone());
+                }
                 comments_used.extend(&mut sl.comment_links.iter().map(|cl| cl.to_string()));
                 true
             })
@@ -330,7 +332,7 @@ impl Collections {
             .collect::<Vec<_>>();
         self.pathways = CollectionWithId::new(pathways)?;
 
-        let stop_points = self
+        let mut stop_points = self
             .stop_points
             .take()
             .into_iter()
@@ -395,7 +397,7 @@ impl Collections {
                 })
                 .collect(),
         )?;
-        let stop_areas = self
+        let mut stop_areas = self
             .stop_areas
             .take()
             .into_iter()
@@ -407,6 +409,9 @@ impl Collections {
                     if let Some(level_id) = &sa.level_id {
                         level_id_used.insert(level_id.clone());
                     }
+                    if let Some(equipment_id) = &sa.equipment_id {
+                        equipments_used.insert(equipment_id.clone());
+                    }
                     comments_used.extend(&mut sa.comment_links.iter().map(|cl| cl.to_string()));
                     true
                 } else {
@@ -416,6 +421,33 @@ impl Collections {
             })
             .collect::<Vec<_>>();
 
+        for sa in stop_areas.iter_mut().filter(|sa| !sa.coord.is_valid()) {
+            debug!(
+                "stop area {} geographic coordinates are not valid and set to (0, 0)",
+                sa.id
+            );
+            sa.coord = Coord::default();
+        }
+
+        for sp in stop_points.iter_mut().filter(|sp| !sp.coord.is_valid()) {
+            debug!(
+                "stop point {} geographic coordinates are not valid and set to (0, 0)",
+                sp.id
+            );
+            sp.coord = Coord::default();
+        }
+
+        for sl in stop_locations
+            .iter_mut()
+            .filter(|sl| sl.stop_type == StopType::StopEntrance && !sl.coord.is_valid())
+        {
+            debug!(
+                "stop access {} geographic coordinates are not valid and set to (0, 0)",
+                sl.id
+            );
+            sl.coord = Coord::default();
+        }
+
         comments_used.extend(self.stop_time_comments.iter().filter_map(
             |((vj_id, _), comment_id)| {
                 if vjs_used.contains(vj_id.as_str()) {
@@ -721,9 +753,7 @@ impl Collections {
     /// If the vehicle didn't stop (point of route) on pickup,
     /// it must not stop on drop off and conversely
     pub fn pickup_drop_off_harmonisation(&mut self) {
-        let vj_idxs: Vec<Idx<VehicleJourney>> =
-            self.vehicle_journeys.iter().map(|(idx, _)| idx).collect();
-        for vj_idx in vj_idxs {
+        for vj_idx in self.vehicle_journeys.indexes() {
             let mut vj = self.vehicle_journeys.index_mut(vj_idx);
             for stop_time in vj
                 .stop_times
@@ -1327,6 +1357,7 @@ impl Model {
         c.enhance_line_opening_time();
         c.pickup_drop_off_harmonisation();
         enhancers::enhance_pickup_dropoff(&mut c);
+        enhancers::memory_shrink(&mut c);
 
         Ok(Model {
             routes_to_stop_points,
@@ -2221,4 +2252,35 @@ mod tests {
             assert_eq!(2, vj.stop_times.len());
         }
     }
+
+    mod check_coord_integrity {
+        use crate::objects::Coord;
+
+        #[test]
+        fn check_valid_coord() {
+            let coord = Coord {
+                lon: 2.372987,
+                lat: 48.844746,
+            };
+            assert!(coord.is_valid());
+        }
+    }
+
+    #[test]
+    fn check_unvalid_lon() {
+        let coord = Coord {
+            lon: -182.,
+            lat: 48.844746,
+        };
+        assert!(!coord.is_valid());
+    }
+
+    #[test]
+    fn check_unvalid_lat() {
+        let coord = Coord {
+            lon: 2.372987,
+            lat: 91.,
+        };
+        assert!(!coord.is_valid());
+    }
 }
