@@ -624,7 +624,7 @@ impl Default for VehicleJourney {
             company_id: "default_company".to_string(),
             trip_property_id: None,
             geometry_id: None,
-            stop_times: vec![],
+            stop_times: Vec::with_capacity(crate::STOP_TIMES_INIT_CAPACITY),
             journey_pattern_id: None,
         }
     }
@@ -980,6 +980,10 @@ impl Coord {
         2. * EARTH_RADIUS * f64::asin(f64::sqrt(x + y))
     }
 
+    pub fn is_valid(&self) -> bool {
+        (self.lon >= -180. && self.lon <= 180.) && (self.lat >= -90. && self.lat <= 90.)
+    }
+
     /// Returns a proxy object allowing to compute approximate
     /// distances for cheap computation.
     ///
